@@ -23,13 +23,14 @@
 #'
 #' @examples
 #' data('sim')
-#' wt = inverse_distance_weight(sim$lo,sim$la,power = 2)
+#' wt = sdsfun::inverse_distance_swm(sf::st_as_sf(sim,coords = c('lo','la')),
+#'                                   power = 2)
 #' psd_pseudop(sim$y,sdsfun::discretize_vector(sim$xa,5),wt)
 #'
 psd_pseudop = \(y,x,wt,cores = 1,
                 seed = 123456789,
                 permutations = 0){
-  qs = psd_spade(y,x,wt)
+  qs = gdverse::psd_spade(y,x,wt)
   if (permutations == 0){
     fd = tibble::tibble("Q-statistic" = qs, "P-value" = "No Pseudo-P Value")
   } else {
@@ -49,17 +50,15 @@ psd_pseudop = \(y,x,wt,cores = 1,
 
     set.seed(seed)
     randomnum = stats::runif(1)
-    xperm = shuffle_vector(x,randomnum,seed = seed)
-    yperm = shuffle_vector(y,randomnum,seed = seed)
+    xperm = gdverse::shuffle_vector(x,randomnum,seed = seed)
+    yperm = gdverse::shuffle_vector(y,randomnum,seed = seed)
     calcul_psd = \(p_shuffle){
-      yobs_shffule = shuffle_vector(yperm,p_shuffle[[2]],seed = seed)
-      xobs_shffule = shuffle_vector(xperm,p_shuffle[[1]],seed = seed)
-      return(psd_spade(yobs_shffule,xobs_shffule,wt))
+      yobs_shffule = gdverse::shuffle_vector(yperm,p_shuffle[[2]],seed = seed)
+      xobs_shffule = gdverse::shuffle_vector(xperm,p_shuffle[[1]],seed = seed)
+      return(gdverse::psd_spade(yobs_shffule,xobs_shffule,wt))
     }
 
     if (doclust) {
-      parallel::clusterExport(cores,c('st_unidisc','robust_disc',
-                                      'psd_spade',"shuffle_vector"))
       out_g = parallel::parLapply(cores,permutation,calcul_psd)
       out_g = as.numeric(do.call(rbind, out_g))
     } else {
@@ -88,7 +87,7 @@ psd_pseudop = \(y,x,wt,cores = 1,
 #' @param yobs Variable Y
 #' @param xobs The original undiscretized covariable X.
 #' @param wt The spatial weight matrix.
-#' @param discnum (optional) Number of multilevel discretization. Default will use `3:22`.
+#' @param discnum (optional) Number of multilevel discretization. Default will use `3:8`.
 #' @param discmethod (optional) The discretization methods. Default will use `quantile`.
 #' If `discmethod` is set to `robust`, the function `robust_disc()` will be used. Conversely,
 #' if `discmethod` is set to `rpart`, the `rpart_disc()` function will be used. Others use
@@ -104,13 +103,13 @@ psd_pseudop = \(y,x,wt,cores = 1,
 #'
 #' @examples
 #' data('sim')
-#' wt = inverse_distance_weight(sim$lo,sim$la)
+#' wt = sdsfun::inverse_distance_swm(sf::st_as_sf(sim,coords = c('lo','la')))
 #' psmd_pseudop(sim$y,sim$xa,wt)
 #'
-psmd_pseudop = \(yobs, xobs, wt, discnum = 3:22,
+psmd_pseudop = \(yobs, xobs, wt, discnum = 3:8,
                  discmethod = 'quantile', cores = 1,
                  seed = 123456789, permutations = 0, ...){
-  qs = psmd_spade(yobs,xobs,wt,discnum,discmethod,cores,seed,...)
+  qs = gdverse::psmd_spade(yobs,xobs,wt,discnum,discmethod,cores,seed,...)
   if (permutations == 0){
     fd = tibble::tibble("Q-statistic" = qs, "P-value" = "No Pseudo-P Value")
   } else {
@@ -130,26 +129,22 @@ psmd_pseudop = \(yobs, xobs, wt, discnum = 3:22,
 
     set.seed(seed)
     randomnum = stats::runif(1)
-    xperm = shuffle_vector(xobs,randomnum,seed = seed)
-    yperm = shuffle_vector(yobs,randomnum,seed = seed)
-    wt_perm = wt
-    seedn = seed
-    discn = discnum
-    discm = discmethod
-    calcul_psmd = \(p_shuffle){
-      xperm_new = shuffle_vector(xperm,p_shuffle[[1]],seed = seed)
-      yperm_new = shuffle_vector(yperm,p_shuffle[[2]],seed = seed)
-      return(psmd_spade(yperm_new,xperm_new,wt_perm,discn,discm,
-                        cores = 1, seed = seedn, ...))
+    xperm = gdverse::shuffle_vector(xobs,randomnum,seed = seed)
+    yperm = gdverse::shuffle_vector(yobs,randomnum,seed = seed)
+    calcul_psmd = \(p_shuffle,wt_perm,seedn,discn,discm){
+      xperm_new = gdverse::shuffle_vector(xperm,p_shuffle[[1]],seed = seed)
+      yperm_new = gdverse::shuffle_vector(yperm,p_shuffle[[2]],seed = seed)
+      return(gdverse::psmd_spade(yperm_new,xperm_new,wt_perm,discn,discm,
+                                 cores = 1, seed = seedn, ...))
     }
 
     if (doclust) {
-      parallel::clusterExport(cores,c('robust_disc','rpart_disc','shuffle_vector','psd_spade',
-                                      'cpsd_spade','psmd_spade','inverse_distance_weight'))
-      out_g = parallel::parLapply(cores,permutation,calcul_psmd)
+      out_g = parallel::parLapply(cores,permutation,calcul_psmd,wt_perm = wt,
+                                  seedn = seed,discn = discnum,discm = discmethod)
       out_g = as.numeric(do.call(rbind, out_g))
     } else {
-      out_g = purrr::map_dbl(permutation,calcul_psmd)
+      out_g = purrr::map_dbl(permutation,calcul_psmd,wt_perm = wt,
+                             seedn = seed,discn = discnum,discm = discmethod)
     }
 
     R = sum(out_g >= qs)
