@@ -53,21 +53,20 @@ spd_lesh = \(formula,data,cores = 1,...){
     dti = data
   }
   xname = colnames(dti)[-which(colnames(dti) == yname)]
-  xs = generate_subsets(xname,empty = FALSE, self = TRUE)
+  xs = sdsfun::generate_subsets(xname,empty = FALSE, self = TRUE)
 
   calcul_theta = \(.x,...){
-    discdf = rpart_disc(paste0(yname,'~',paste(.x,collapse = '+')),data = dti,...)
-    qv = factor_detector(dti[,yname,drop = TRUE],discdf)[[1]]
+    discdf = gdverse::rpart_disc(paste0(yname,'~',paste(.x,collapse = '+')),data = dti,...)
+    qv = gdverse::factor_detector(dti[,yname,drop = TRUE],discdf)[[1]]
     names(qv) = 'qv_theta'
     return(qv)
   }
 
   if (doclust) {
-    parallel::clusterExport(cores,c('rpart_disc','factor_detector'))
     out_g = parallel::parLapply(cores,xs,calcul_theta,...)
     out_g = tibble::as_tibble(do.call(rbind, out_g))
   } else {
-    out_g = purrr::map_dfr(xs, calcul_theta)
+    out_g = purrr::map_dfr(xs,calcul_theta,...)
   }
   qv = dplyr::pull(out_g,qv_theta)
   m = length(xname)
@@ -87,7 +86,7 @@ spd_lesh = \(formula,data,cores = 1,...){
 
   calcul_shap = \(xvar){
     fullxvar = xname[-which(xname == xvar)]
-    fullvar = generate_subsets(fullxvar,empty = FALSE,self = TRUE)
+    fullvar = sdsfun::generate_subsets(fullxvar,empty = FALSE,self = TRUE)
 
     calcul_unishap = \(xvar,fullxvar,namelist,valuevec){
       n = length(fullxvar)
@@ -113,7 +112,6 @@ spd_lesh = \(formula,data,cores = 1,...){
   }
 
   if (doclust) {
-    parallel::clusterExport(cores,c('generate_subsets'))
     out_g = parallel::parLapply(cores,xname,calcul_shap)
     out_g = tibble::as_tibble(do.call(rbind, out_g))
   } else {
@@ -125,59 +123,3 @@ spd_lesh = \(formula,data,cores = 1,...){
     dplyr::arrange(dplyr::desc(spd_theta))
   return(out_g)
 }
-
-#------------------------------------------------------------------------------
-#-------            Previous implementation of spd_lesh                --------
-#------------------------------------------------------------------------------
-# spd_lesh = \(formula,data,cores = 1,...){
-#   doclust = FALSE
-#   if (inherits(cores, "cluster")) {
-#     doclust = TRUE
-#   } else if (cores > 1) {
-#     doclust = TRUE
-#     cores = parallel::makeCluster(cores)
-#     on.exit(parallel::stopCluster(cores), add = TRUE)
-#   }
-#
-#   formula = stats::as.formula(formula)
-#   formula.vars = all.vars(formula)
-#   yname = formula.vars[1]
-#   if (formula.vars[2] != "."){
-#     dti = dplyr::select(data,dplyr::all_of(formula.vars))
-#   } else {
-#     dti = data
-#   }
-#   xname = colnames(dti)[-which(colnames(dti) == yname)]
-#   m = length(xname)
-#   mf = factorial(m)
-#
-#   calcul_theta = \(xvar,fullxvar){
-#     n = length(fullxvar)
-#     df1 = rpart_disc(paste0(yname,'~',paste(c(xvar,fullxvar),collapse = '+')),data = dti,...)
-#     df2 = rpart_disc(paste0(yname,'~',paste(fullxvar,collapse = '+')),data = dti,...)
-#     v1 = factor_detector(dti[,yname,drop = TRUE],df1)[[1]]
-#     v2 = factor_detector(dti[,yname,drop = TRUE],df2)[[1]]
-#     thetax = factorial(n) * factorial(m - n - 1) * (v1 - v2) / mf
-#     return(thetax)
-#   }
-#   calcul_shap = \(xvar){
-#     fullxvar = xname[-which(xname == xvar)]
-#     fullvar = generate_subsets(fullxvar,empty = FALSE,self = TRUE)
-#     thetaxs = purrr::map_dbl(fullvar, \(x) calcul_theta(xvar,x))
-#     thetax = sum(thetaxs)
-#     names(thetax) = 'spd_theta'
-#     return(thetax)
-#   }
-#
-#   if (doclust) {
-#     parallel::clusterExport(cores,c('generate_subsets','rpart_disc','factor_detector'))
-#     out_g = parallel::parLapply(cores,xname,calcul_shap)
-#     out_g = tibble::as_tibble(do.call(rbind, out_g))
-#   } else {
-#     out_g = purrr::map_dfr(xname,calcul_shap)
-#   }
-#   out_g = tibble::tibble(varibale = xname) %>%
-#     dplyr::bind_cols(out_g) %>%
-#     dplyr::arrange(dplyr::desc(spd_theta))
-#   return(out_g)
-# }
